"""This is the installation toolset for this project."""
from setuptools import setup, find_packages

with open("README.rst", "r") as fh:
    long_description = fh.read()

setup(
    name="charmer",
    version="0.1.0",
    author="Ramon Hagenaars",
    description="A commandline interface for creating project structures",
    long_description=long_description,
    packages=find_packages(exclude=("tests",)),
    entry_points={"console_scripts": ["charm=charmer.__main__:main"]},
)
